# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkhbase.endpoint import endpoint_data

class ResizeMultiZoneClusterNodeCountRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'HBase', '2019-01-01', 'ResizeMultiZoneClusterNodeCount','hbase')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_PrimaryVSwitchId(self):
		return self.get_query_params().get('PrimaryVSwitchId')

	def set_PrimaryVSwitchId(self,PrimaryVSwitchId):
		self.add_query_param('PrimaryVSwitchId',PrimaryVSwitchId)

	def get_StandbyVSwitchId(self):
		return self.get_query_params().get('StandbyVSwitchId')

	def set_StandbyVSwitchId(self,StandbyVSwitchId):
		self.add_query_param('StandbyVSwitchId',StandbyVSwitchId)

	def get_LogNodeCount(self):
		return self.get_query_params().get('LogNodeCount')

	def set_LogNodeCount(self,LogNodeCount):
		self.add_query_param('LogNodeCount',LogNodeCount)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_PrimaryCoreNodeCount(self):
		return self.get_query_params().get('PrimaryCoreNodeCount')

	def set_PrimaryCoreNodeCount(self,PrimaryCoreNodeCount):
		self.add_query_param('PrimaryCoreNodeCount',PrimaryCoreNodeCount)

	def get_CoreNodeCount(self):
		return self.get_query_params().get('CoreNodeCount')

	def set_CoreNodeCount(self,CoreNodeCount):
		self.add_query_param('CoreNodeCount',CoreNodeCount)

	def get_StandbyCoreNodeCount(self):
		return self.get_query_params().get('StandbyCoreNodeCount')

	def set_StandbyCoreNodeCount(self,StandbyCoreNodeCount):
		self.add_query_param('StandbyCoreNodeCount',StandbyCoreNodeCount)

	def get_ArbiterVSwitchId(self):
		return self.get_query_params().get('ArbiterVSwitchId')

	def set_ArbiterVSwitchId(self,ArbiterVSwitchId):
		self.add_query_param('ArbiterVSwitchId',ArbiterVSwitchId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkhbase.endpoint import endpoint_data

class RelateDbForHBaseHaRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'HBase', '2019-01-01', 'RelateDbForHBaseHa','hbase')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_HaMigrateType(self):
		return self.get_query_params().get('HaMigrateType')

	def set_HaMigrateType(self,HaMigrateType):
		self.add_query_param('HaMigrateType',HaMigrateType)

	def get_HaActiveHdfsUri(self):
		return self.get_query_params().get('HaActiveHdfsUri')

	def set_HaActiveHdfsUri(self,HaActiveHdfsUri):
		self.add_query_param('HaActiveHdfsUri',HaActiveHdfsUri)

	def get_HaStandbyVersion(self):
		return self.get_query_params().get('HaStandbyVersion')

	def set_HaStandbyVersion(self,HaStandbyVersion):
		self.add_query_param('HaStandbyVersion',HaStandbyVersion)

	def get_IsStandbyStandard(self):
		return self.get_query_params().get('IsStandbyStandard')

	def set_IsStandbyStandard(self,IsStandbyStandard):
		self.add_query_param('IsStandbyStandard',IsStandbyStandard)

	def get_HaActiveClusterKey(self):
		return self.get_query_params().get('HaActiveClusterKey')

	def set_HaActiveClusterKey(self,HaActiveClusterKey):
		self.add_query_param('HaActiveClusterKey',HaActiveClusterKey)

	def get_HaStandbyPassword(self):
		return self.get_query_params().get('HaStandbyPassword')

	def set_HaStandbyPassword(self,HaStandbyPassword):
		self.add_query_param('HaStandbyPassword',HaStandbyPassword)

	def get_HaStandbyClusterKey(self):
		return self.get_query_params().get('HaStandbyClusterKey')

	def set_HaStandbyClusterKey(self,HaStandbyClusterKey):
		self.add_query_param('HaStandbyClusterKey',HaStandbyClusterKey)

	def get_HaStandbyHbaseFsDir(self):
		return self.get_query_params().get('HaStandbyHbaseFsDir')

	def set_HaStandbyHbaseFsDir(self,HaStandbyHbaseFsDir):
		self.add_query_param('HaStandbyHbaseFsDir',HaStandbyHbaseFsDir)

	def get_HaActiveHbaseFsDir(self):
		return self.get_query_params().get('HaActiveHbaseFsDir')

	def set_HaActiveHbaseFsDir(self,HaActiveHbaseFsDir):
		self.add_query_param('HaActiveHbaseFsDir',HaActiveHbaseFsDir)

	def get_HaActiveDBType(self):
		return self.get_query_params().get('HaActiveDBType')

	def set_HaActiveDBType(self,HaActiveDBType):
		self.add_query_param('HaActiveDBType',HaActiveDBType)

	def get_HaActivePassword(self):
		return self.get_query_params().get('HaActivePassword')

	def set_HaActivePassword(self,HaActivePassword):
		self.add_query_param('HaActivePassword',HaActivePassword)

	def get_IsActiveStandard(self):
		return self.get_query_params().get('IsActiveStandard')

	def set_IsActiveStandard(self,IsActiveStandard):
		self.add_query_param('IsActiveStandard',IsActiveStandard)

	def get_HaStandbyUser(self):
		return self.get_query_params().get('HaStandbyUser')

	def set_HaStandbyUser(self,HaStandbyUser):
		self.add_query_param('HaStandbyUser',HaStandbyUser)

	def get_HaActive(self):
		return self.get_query_params().get('HaActive')

	def set_HaActive(self,HaActive):
		self.add_query_param('HaActive',HaActive)

	def get_HaStandby(self):
		return self.get_query_params().get('HaStandby')

	def set_HaStandby(self,HaStandby):
		self.add_query_param('HaStandby',HaStandby)

	def get_HaStandbyHdfsUri(self):
		return self.get_query_params().get('HaStandbyHdfsUri')

	def set_HaStandbyHdfsUri(self,HaStandbyHdfsUri):
		self.add_query_param('HaStandbyHdfsUri',HaStandbyHdfsUri)

	def get_HaActiveVersion(self):
		return self.get_query_params().get('HaActiveVersion')

	def set_HaActiveVersion(self,HaActiveVersion):
		self.add_query_param('HaActiveVersion',HaActiveVersion)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_HaStandbyDBType(self):
		return self.get_query_params().get('HaStandbyDBType')

	def set_HaStandbyDBType(self,HaStandbyDBType):
		self.add_query_param('HaStandbyDBType',HaStandbyDBType)

	def get_HaTables(self):
		return self.get_query_params().get('HaTables')

	def set_HaTables(self,HaTables):
		self.add_query_param('HaTables',HaTables)

	def get_HaActiveUser(self):
		return self.get_query_params().get('HaActiveUser')

	def set_HaActiveUser(self,HaActiveUser):
		self.add_query_param('HaActiveUser',HaActiveUser)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkhbase.endpoint import endpoint_data

class EnableHBaseueModuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'HBase', '2019-01-01', 'EnableHBaseueModule','hbase')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ClientToken(self):
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self,ClientToken):
		self.add_query_param('ClientToken',ClientToken)

	def get_ModuleTypeName(self):
		return self.get_query_params().get('ModuleTypeName')

	def set_ModuleTypeName(self,ModuleTypeName):
		self.add_query_param('ModuleTypeName',ModuleTypeName)

	def get_HbaseueClusterId(self):
		return self.get_query_params().get('HbaseueClusterId')

	def set_HbaseueClusterId(self,HbaseueClusterId):
		self.add_query_param('HbaseueClusterId',HbaseueClusterId)

	def get_BdsId(self):
		return self.get_query_params().get('BdsId')

	def set_BdsId(self,BdsId):
		self.add_query_param('BdsId',BdsId)

	def get_ModuleClusterName(self):
		return self.get_query_params().get('ModuleClusterName')

	def set_ModuleClusterName(self,ModuleClusterName):
		self.add_query_param('ModuleClusterName',ModuleClusterName)

	def get_AutoRenewPeriod(self):
		return self.get_query_params().get('AutoRenewPeriod')

	def set_AutoRenewPeriod(self,AutoRenewPeriod):
		self.add_query_param('AutoRenewPeriod',AutoRenewPeriod)

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_DiskSize(self):
		return self.get_query_params().get('DiskSize')

	def set_DiskSize(self,DiskSize):
		self.add_query_param('DiskSize',DiskSize)

	def get_MasterInstanceType(self):
		return self.get_query_params().get('MasterInstanceType')

	def set_MasterInstanceType(self,MasterInstanceType):
		self.add_query_param('MasterInstanceType',MasterInstanceType)

	def get_DiskType(self):
		return self.get_query_params().get('DiskType')

	def set_DiskType(self,DiskType):
		self.add_query_param('DiskType',DiskType)

	def get_VswitchId(self):
		return self.get_query_params().get('VswitchId')

	def set_VswitchId(self,VswitchId):
		self.add_query_param('VswitchId',VswitchId)

	def get_PeriodUnit(self):
		return self.get_query_params().get('PeriodUnit')

	def set_PeriodUnit(self,PeriodUnit):
		self.add_query_param('PeriodUnit',PeriodUnit)

	def get_CoreInstanceType(self):
		return self.get_query_params().get('CoreInstanceType')

	def set_CoreInstanceType(self,CoreInstanceType):
		self.add_query_param('CoreInstanceType',CoreInstanceType)

	def get_VpcId(self):
		return self.get_query_params().get('VpcId')

	def set_VpcId(self,VpcId):
		self.add_query_param('VpcId',VpcId)

	def get_NodeCount(self):
		return self.get_query_params().get('NodeCount')

	def set_NodeCount(self,NodeCount):
		self.add_query_param('NodeCount',NodeCount)

	def get_ZoneId(self):
		return self.get_query_params().get('ZoneId')

	def set_ZoneId(self,ZoneId):
		self.add_query_param('ZoneId',ZoneId)

	def get_PayType(self):
		return self.get_query_params().get('PayType')

	def set_PayType(self,PayType):
		self.add_query_param('PayType',PayType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkhbase.endpoint import endpoint_data

class EvaluateMultiZoneResourceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'HBase', '2019-01-01', 'EvaluateMultiZoneResource','hbase')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ArchVersion(self):
		return self.get_query_params().get('ArchVersion')

	def set_ArchVersion(self,ArchVersion):
		self.add_query_param('ArchVersion',ArchVersion)

	def get_ClusterName(self):
		return self.get_query_params().get('ClusterName')

	def set_ClusterName(self,ClusterName):
		self.add_query_param('ClusterName',ClusterName)

	def get_EngineVersion(self):
		return self.get_query_params().get('EngineVersion')

	def set_EngineVersion(self,EngineVersion):
		self.add_query_param('EngineVersion',EngineVersion)

	def get_LogDiskType(self):
		return self.get_query_params().get('LogDiskType')

	def set_LogDiskType(self,LogDiskType):
		self.add_query_param('LogDiskType',LogDiskType)

	def get_PrimaryVSwitchId(self):
		return self.get_query_params().get('PrimaryVSwitchId')

	def set_PrimaryVSwitchId(self,PrimaryVSwitchId):
		self.add_query_param('PrimaryVSwitchId',PrimaryVSwitchId)

	def get_LogInstanceType(self):
		return self.get_query_params().get('LogInstanceType')

	def set_LogInstanceType(self,LogInstanceType):
		self.add_query_param('LogInstanceType',LogInstanceType)

	def get_AutoRenewPeriod(self):
		return self.get_query_params().get('AutoRenewPeriod')

	def set_AutoRenewPeriod(self,AutoRenewPeriod):
		self.add_query_param('AutoRenewPeriod',AutoRenewPeriod)

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_LogNodeCount(self):
		return self.get_query_params().get('LogNodeCount')

	def set_LogNodeCount(self,LogNodeCount):
		self.add_query_param('LogNodeCount',LogNodeCount)

	def get_SecurityIPList(self):
		return self.get_query_params().get('SecurityIPList')

	def set_SecurityIPList(self,SecurityIPList):
		self.add_query_param('SecurityIPList',SecurityIPList)

	def get_PeriodUnit(self):
		return self.get_query_params().get('PeriodUnit')

	def set_PeriodUnit(self,PeriodUnit):
		self.add_query_param('PeriodUnit',PeriodUnit)

	def get_CoreDiskType(self):
		return self.get_query_params().get('CoreDiskType')

	def set_CoreDiskType(self,CoreDiskType):
		self.add_query_param('CoreDiskType',CoreDiskType)

	def get_ArbiterZoneId(self):
		return self.get_query_params().get('ArbiterZoneId')

	def set_ArbiterZoneId(self,ArbiterZoneId):
		self.add_query_param('ArbiterZoneId',ArbiterZoneId)

	def get_ClientToken(self):
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self,ClientToken):
		self.add_query_param('ClientToken',ClientToken)

	def get_MultiZoneCombination(self):
		return self.get_query_params().get('MultiZoneCombination')

	def set_MultiZoneCombination(self,MultiZoneCombination):
		self.add_query_param('MultiZoneCombination',MultiZoneCombination)

	def get_PrimaryZoneId(self):
		return self.get_query_params().get('PrimaryZoneId')

	def set_PrimaryZoneId(self,PrimaryZoneId):
		self.add_query_param('PrimaryZoneId',PrimaryZoneId)

	def get_Engine(self):
		return self.get_query_params().get('Engine')

	def set_Engine(self,Engine):
		self.add_query_param('Engine',Engine)

	def get_StandbyVSwitchId(self):
		return self.get_query_params().get('StandbyVSwitchId')

	def set_StandbyVSwitchId(self,StandbyVSwitchId):
		self.add_query_param('StandbyVSwitchId',StandbyVSwitchId)

	def get_StandbyZoneId(self):
		return self.get_query_params().get('StandbyZoneId')

	def set_StandbyZoneId(self,StandbyZoneId):
		self.add_query_param('StandbyZoneId',StandbyZoneId)

	def get_MasterInstanceType(self):
		return self.get_query_params().get('MasterInstanceType')

	def set_MasterInstanceType(self,MasterInstanceType):
		self.add_query_param('MasterInstanceType',MasterInstanceType)

	def get_CoreNodeCount(self):
		return self.get_query_params().get('CoreNodeCount')

	def set_CoreNodeCount(self,CoreNodeCount):
		self.add_query_param('CoreNodeCount',CoreNodeCount)

	def get_LogDiskSize(self):
		return self.get_query_params().get('LogDiskSize')

	def set_LogDiskSize(self,LogDiskSize):
		self.add_query_param('LogDiskSize',LogDiskSize)

	def get_CoreInstanceType(self):
		return self.get_query_params().get('CoreInstanceType')

	def set_CoreInstanceType(self,CoreInstanceType):
		self.add_query_param('CoreInstanceType',CoreInstanceType)

	def get_CoreDiskSize(self):
		return self.get_query_params().get('CoreDiskSize')

	def set_CoreDiskSize(self,CoreDiskSize):
		self.add_query_param('CoreDiskSize',CoreDiskSize)

	def get_VpcId(self):
		return self.get_query_params().get('VpcId')

	def set_VpcId(self,VpcId):
		self.add_query_param('VpcId',VpcId)

	def get_PayType(self):
		return self.get_query_params().get('PayType')

	def set_PayType(self,PayType):
		self.add_query_param('PayType',PayType)

	def get_ArbiterVSwitchId(self):
		return self.get_query_params().get('ArbiterVSwitchId')

	def set_ArbiterVSwitchId(self,ArbiterVSwitchId):
		self.add_query_param('ArbiterVSwitchId',ArbiterVSwitchId)